Авторы
======

Список замечательных людей, принявших участие в развитии проекта:

* Михаил "`marazmiki <https://github.com/marazmiki>`_" Пороховниченко <marazmiki@gmail.com>
* Игорь "`itoldya <https://github.com/itoldya>`_" Исаев <i-told@ya.ru>
* Михаил "`mike-grayhat <https://github.com/mike-grayhat>`_" Оськин
* Виталий "`vetal4444 <https://github.com/vetal4444>`_" Савченко <vetal4444@gmail.com>
* Антон "`Forever-Young <https://github.com/Forever-Young>`_" Новосёлов <anton.novosyolov@gmail.com>
* Денис "`dkopitsa <https://github.com/dkopitsa>`_" Копица <denis.kopitsa@gmail.com>
* Максим "`sdfsdhgjkbmnmxc <https://github.com/sdfsdhgjkbmnmxc>`_" Оранский <maxim.oransky@gmail.com>
* `Haos616 <https://github.com/Haos616>`_ <Haos616@Gmail.com>
* `mcd-php <https://github.com/mcd-php>`_

